==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1beta1VolumeAttachmentSourceFluentImpl.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class V1beta1VolumeAttachmentSourceFluentImpl<A extends V1beta1VolumeAttachmentSourceFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1beta1VolumeAttachmentSourceFluent<A>{

    private String persistentVolumeName;

    public V1beta1VolumeAttachmentSourceFluentImpl(){
    }
    public V1beta1VolumeAttachmentSourceFluentImpl(V1beta1VolumeAttachmentSource instance){
            this.withPersistentVolumeName(instance.getPersistentVolumeName());

    }

    public String getPersistentVolumeName(){
            return this.persistentVolumeName;
    }

    public A withPersistentVolumeName(String persistentVolumeName){
            this.persistentVolumeName=persistentVolumeName; return (A) this;
    }

    public Boolean hasPersistentVolumeName(){
            return this.persistentVolumeName != null;
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1beta1VolumeAttachmentSourceFluentImpl that = (V1beta1VolumeAttachmentSourceFluentImpl) o;
            if (persistentVolumeName != null ? !persistentVolumeName.equals(that.persistentVolumeName) :that.persistentVolumeName != null) return false;
            return true;
    }




}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1beta1VolumeAttachmentSourceFluentImpl.java <==
package io.kubernetes.client.models;

import java.lang.StringBuffer;
import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class V1beta1VolumeAttachmentSourceFluentImpl<A extends V1beta1VolumeAttachmentSourceFluent<A>> extends io.kubernetes.client.fluent.BaseFluent<A> implements V1beta1VolumeAttachmentSourceFluent<A>{

    private String persistentVolumeName;

    public V1beta1VolumeAttachmentSourceFluentImpl(){
    }
    public V1beta1VolumeAttachmentSourceFluentImpl(V1beta1VolumeAttachmentSource instance){
            this.withPersistentVolumeName(instance.getPersistentVolumeName());

    }

    public String getPersistentVolumeName(){
            return this.persistentVolumeName;
    }

    public A withPersistentVolumeName(String persistentVolumeName){
            this.persistentVolumeName=persistentVolumeName; return (A) this;
    }

    public Boolean hasPersistentVolumeName(){
            return this.persistentVolumeName != null;
    }

    public A withNewPersistentVolumeName(String arg1){
            return (A)withPersistentVolumeName(new String(arg1));
    }

    public A withNewPersistentVolumeName(StringBuilder arg1){
            return (A)withPersistentVolumeName(new String(arg1));
    }

    public A withNewPersistentVolumeName(StringBuffer arg1){
            return (A)withPersistentVolumeName(new String(arg1));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            V1beta1VolumeAttachmentSourceFluentImpl that = (V1beta1VolumeAttachmentSourceFluentImpl) o;
            if (persistentVolumeName != null ? !persistentVolumeName.equals(that.persistentVolumeName) :that.persistentVolumeName != null) return false;
            return true;
    }




}
